.. code-block:: bash

   Usage: nessie remote set-head [OPTIONS] HEAD

     Set current default branch. If -d is passed it will remove the default branch.

   Options:
     -d, --delete  delete the default branch
     --help        Show this message and exit.


